@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.4.1');
+our $VERSION = version->new('0.4.2');
 our $EXIT    = 1;
 
 has options => (
@@ -260,6 +260,10 @@ sub process {
                 $short = $1;
                 $arg_data  = $2;
             }
+            elsif ( $arg eq '--' ) {
+                push @{ $self->files }, @args;
+                die "last\n";
+            }
             else {
                 push @{ $self->files }, $arg;
                 die $self->sub_command ? "last\n" : "next\n";
@@ -518,7 +522,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.4.1.
+This documentation refers to Getopt::Alt version 0.4.2.
 
 =head1 SYNOPSIS
 
@@ -811,7 +815,7 @@ file to get auto-completion.
     }
     complete -F _eg eg
 
-B<Note>: This is different from version 0.4.1 and earlier
+B<Note>: This is different from version 0.4.2 and earlier
 
 =head1 DIAGNOSTICS
 
